@@ -92,20 +92,13 @@ plot_effects_commOccu <- function(object,
     
     has_squared <- cov_info_subset$has_quadratic[cov]
     if(paste0(current_cov, keyword_quadratic) %in% params_covariate){
-      #has_squared <- TRUE
       squared_cov <- paste0(current_cov, keyword_quadratic)
-    } #else {
-      #has_squared <- FALSE
-    #}
+    } 
     
     # determine data type of current covariate
     covariate_is_numeric <- cov_info_subset$data_type [cov] == "cont"
     covariate_is_factor  <- cov_info_subset$data_type [cov] == "categ"
     
-    
-    # covariate_is_fixed <- !cov_info_subset$ranef[cov]
-    # covariate_is_ranef <- cov_info_subset$ranef[cov]
-    
     effect_type <- ifelse(cov_info_subset$ranef[cov], "ranef",
                           ifelse(cov_info_subset$independent[cov], "independent", "fixed"))
     
@@ -160,17 +153,6 @@ plot_effects_commOccu <- function(object,
       
         
         
-      # # get intercepts
-      # if(!paste0(keyword_submodel_short, "0.mean") %in%  object@params) {
-      #   # fixed intercept
-      #   out_intercept[,i,] <- posterior_matrix[, grepl(paste0(keyword_submodel_short, "0$"), colnames(posterior_matrix))] 
-      # } else {
-      #   
-      #   # random intercept
-      #   out_intercept[,i,] <- posterior_matrix[, colnames(posterior_matrix) %in% paste0(keyword_submodel_short, "0", "[", i, "]")] 
-      # }
-      
-      
       if(covariate_is_numeric) {
         
         if(effect_type == "fixed") {
@@ -290,11 +272,7 @@ plot_effects_commOccu <- function(object,
                        ifelse(has_squared, " (with quadratic term)", ""),
                        ifelse(is_squared, " quadratic term (no linear term)", ""))
     
-    
-    # make cran checks happy
-    lower <- NULL
-    upper <- NULL
-    
+
     # for squared covariates which have no unsquared version, sqrt-transform covariate and add expand covariate range to negative values (by mirr)
     if(is_squared & !has_squared) {
       vals[,1] <- sqrt(vals[,1])
@@ -323,7 +301,7 @@ plot_effects_commOccu <- function(object,
     
     if(covariate_is_numeric){
       
-      p <- ggplot(vals, aes_string(x = params_covariate[[cov]], y = "mean", group = "Species")) + 
+      p <- ggplot(vals, aes(x = .data[[params_covariate[[cov]]]], y = .data[["mean"]], group = .data[["Species"]])) + 
         geom_line() +
         theme_bw() +
         ggtitle(label = main,
@@ -339,7 +317,7 @@ plot_effects_commOccu <- function(object,
       # note for later, can optionally plot all species in  one plot if combine = TRUE (= ggplot code to this point)
       if(!combine){
         p <- p + facet_wrap(~Species) +
-          geom_ribbon(aes_string(ymin = "lower", ymax = "upper"), alpha = 0.2)
+          geom_ribbon(aes(ymin = .data[["lower"]], ymax = .data[["upper"]]), alpha = 0.2)
       }
     }
     
@@ -352,17 +330,17 @@ plot_effects_commOccu <- function(object,
                            levels = levels(object@data[[current_cov]]))
       } 
       
-      p <- ggplot(vals, aes_string(x = params_covariate[[cov]], y = "mean", group = "Species")) + 
+      p <- ggplot(vals, aes(x = .data[[params_covariate[[cov]]]], y = .data[["mean"]], group = .data[["Species"]])) + 
         geom_col() +
         facet_wrap(~Species) +
-        geom_linerange(aes(ymin = "lower", ymax = "upper")) +
+        geom_linerange(aes(ymin = lower, ymax = upper)) +
         theme_bw() +
         ggtitle(label = main,
                 subtitle = subtitle) +
         xlab (current_cov) +
         ylab(ylabel) +
         theme(panel.grid.minor = element_blank())
-      
+
       if(.hasSlot(object, "model")) if(object@model == "Occupancy") p <- p + ylim(0, 1) 
       if(!.hasSlot(object, "model")) p <- p + ylim(0, 1) 
       
@@ -413,7 +391,7 @@ plot_effects_commOccu <- function(object,
   #' @return A list of ggplot objects (one list item per covariate).
   #' @export
   #' @importFrom ggplot2 geom_vline geom_linerange geom_pointrange element_blank theme labs expr
-  #' @importFrom ggplot2 scale_color_manual scale_y_discrete aes_string vars facet_grid facet_wrap ylim geom_col
+  #' @importFrom ggplot2 scale_color_manual scale_y_discrete aes vars facet_grid facet_wrap ylim geom_col
   # @import coda
   #'
   setMethod("plot_effects", 
@@ -521,11 +499,6 @@ plot_coef_commOccu <- function(object,
     covariate_is_factor  <- cov_info_subset$data_type [cov] == "categ"
     
     
-    # covariate_is_fixed <- !cov_info_subset$ranef[cov]
-    # covariate_is_indep <- cov_info_subset$independent[cov]
-    # covariate_is_ranef <- cov_info_subset$ranef[cov]
-    
-    
     
     effect_type <- ifelse(cov_info_subset$ranef[cov], "ranef",
                           ifelse(cov_info_subset$independent[cov], "independent", "fixed"))
@@ -749,7 +722,7 @@ plot_coef_commOccu <- function(object,
     if(!combine){
       
       
-      p_list[[cov]] <- ggplot (df_quantiles_i, aes_string(y = "species", x = "median", color = color_by)) +
+      p_list[[cov]] <- ggplot (df_quantiles_i, aes(y = .data[["species"]], x = .data[["median"]], color = color_by))
         
         if(community_lines) {
         # community effect
@@ -766,8 +739,8 @@ plot_coef_commOccu <- function(object,
         geom_vline(xintercept = 0, alpha = alpha_zero) +
         
         # species effects
-        geom_pointrange(aes_string(xmin = "lower_outer", xmax = "upper_outer")) + 
-        geom_linerange( aes_string(xmin = "lower_inner", xmax = "upper_inner"), linewidth = 1) +
+        geom_pointrange(aes(xmin = .data[["lower_outer"]], xmax = .data[["upper_outer"]])) + 
+        geom_linerange( aes(xmin = .data[["lower_inner"]], xmax = .data[["upper_inner"]]), linewidth = 1) +
         facet_grid(rows = vars(type),
                    cols = vars(covariate),
                    scales = scales,
@@ -811,7 +784,7 @@ plot_coef_commOccu <- function(object,
     df_quantiles_all$species <- factor(df_quantiles_all$species, 
                                        levels = rev(sort(unique(as.character(df_quantiles_all$species)))))
     
-    p <- ggplot (df_quantiles_all, aes_string(y = "species", x = "median", color = color_by))
+    p <- ggplot (df_quantiles_all, aes(y = .data[["species"]], x = .data[["median"]], color = color_by))
       
     if(community_lines)  {
       # community effect
@@ -825,8 +798,8 @@ plot_coef_commOccu <- function(object,
     }
     p <- p + geom_vline(xintercept = 0, alpha = alpha_zero) +
       # species effects
-      geom_pointrange(aes_string(xmin = "lower_outer", xmax = "upper_outer")) + 
-      geom_linerange (aes_string(xmin = "lower_inner", xmax = "upper_inner"), size = 1) +
+      geom_pointrange(aes(xmin = .data[["lower_outer"]], xmax = .data[["upper_outer"]])) + 
+      geom_linerange (aes(xmin = .data[["lower_inner"]], xmax = .data[["upper_inner"]]), linewidth = 1) +
       facet_grid(rows = vars(type), 
                  cols = vars(covariate),
                  scales = scales, 
